@@ -1,5 +1,5 @@
-points.TimeIntervalDataFrame <- function (x, y=NULL, cursor=NULL,
-					type='p', lty=1:6, lwd=1, pch=1:25, col=NULL, ...) {
+points.TimeIntervalDataFrame <- function (x, y=NULL, cursor=NULL, type='p',
+					  lty=1:6, lwd=1, pch=1:25, col=NULL, ...) {
 	if (is.null(cursor)) {
 		if (is.null(y)) y <- names(x)
 		y <- data.frame (x[y])
@@ -8,7 +8,8 @@ points.TimeIntervalDataFrame <- function (x, y=NULL, cursor=NULL,
 		lty <- rep (lty, length.out=length(y))
 		lwd <- rep (lwd, length.out=length(y))
 		if( is.data.frame(pch) )
-			pch <- as.list(pch[rep(1:length(pch), length.out=length(y))]) else
+			pch <- as.list(pch[rep(1:length(pch),
+					       length.out=length(y))]) else
 			pch <- rep (pch, length.out=length(y))
 		if (is.null(col))
 			col <- sample (colors(), length(y)) else
@@ -40,11 +41,11 @@ points.TimeIntervalDataFrame <- function (x, y=NULL, cursor=NULL,
 	}
 }
 
-lines.TimeIntervalDataFrame <- function (x, y=NULL, cursor=NULL,
-					type='l', lty=1:6, lwd=1, pch=1:25, col=NULL, ...)
+lines.TimeIntervalDataFrame <- function (x, y=NULL, cursor=NULL, type='l',
+					 lty=1:6, lwd=1, pch=1:25, col=NULL, ...)
 {
-	invisible (points (x=x, y=y, cursor=cursor, type=type, lty=lty, lwd=lwd, pch=pch,
-			col=col, ...))
+	invisible (points (x=x, y=y, cursor=cursor, type=type, lty=lty, lwd=lwd,
+			   pch=pch, col=col, ...))
 }
 
 plot.TimeIntervalDataFrame <- function (x, y=NULL, cursor=NULL,
@@ -69,19 +70,31 @@ plot.TimeIntervalDataFrame <- function (x, y=NULL, cursor=NULL,
 			axis.POSIXct (1, c(start(x), end(x)) ) 
 			box()
 		}
-		invisible (points (x=x, y=names(y), cursor=cursor, type=type, lty=lty,
-				lwd=lwd, pch=pch, col=col, ...))
+		invisible (points (x=x, y=names(y), cursor=cursor, type=type,
+				   lty=lty, lwd=lwd, pch=pch, col=col, ...))
 	} else {
 		x <- as.TimeInstantDataFrame (x, cursor=cursor)
-		invisible(plot (x=x, y=y, type=type, lty=lty, lwd=lwd, pch=pch, col=col,
-		      xlim=xlim, ylim=ylim, log=log,
-		      main=main, sub=sub, xlab=xlab, ylab=ylab, ann=ann,
-		      axes=axes, asp=asp, ...))
+		invisible(plot (x=x, y=y, type=type, lty=lty, lwd=lwd, pch=pch,
+			col=col,
+  			xlim=xlim, ylim=ylim, log=log,
+  			main=main, sub=sub, xlab=xlab, ylab=ylab, ann=ann,
+  			axes=axes, asp=asp, ...))
 	}
 }
 
-points.TimeInstantDataFrame <- function (x, y=NULL,
-					type='p', lty=1:6, lwd=1, pch=1:25, col=NULL, ...) {
+barplot.TimeIntervalDataFrame <- function(height, format='', ...) {
+	dots <- list(...)
+	if( !'names.arg' %in% names(dots) )
+		dots$names.arg <- paste(
+			format(start(height), format=format),
+			format(end(height), format=format),
+			sep='\n')
+	height <- t(as.data.frame(height))
+	do.call(barplot, c(height=list(height), dots))
+}
+
+points.TimeInstantDataFrame <- function (x, y=NULL, type='p', lty=1:6,
+					 lwd=1, pch=1:25, col=NULL, ...) {
 	if (is.null(y)) y <- names(x)
 	y <- data.frame (x[y])
 
@@ -97,7 +110,8 @@ points.TimeInstantDataFrame <- function (x, y=NULL,
 		col <- rep (col, length.out=length(y))
 	
 	# plotting
-	trash <- mapply (points, y=y, pch=pch, col=col, type=type, lty=lty, lwd=lwd, ...,
+	trash <- mapply (points, y=y, pch=pch, col=col, type=type, lty=lty,
+			 lwd=lwd, ...,
 			MoreArgs=list(x=when(x)))
 	pch <- sapply(pch, paste, collapse=', ')
 	if (length(y) > 0)
@@ -105,13 +119,15 @@ points.TimeInstantDataFrame <- function (x, y=NULL,
 				stringsAsFactors=FALSE))
 }
 
-lines.TimeInstantDataFrame <- function (x, y=NULL,
-					type='l', lty=1:6, lwd=1, pch=1:25, col=NULL, ...) {
-	invisible (points (x=x, y=y, type=type, lty=lty, lwd=lwd, pch=pch, col=col, ...))
+lines.TimeInstantDataFrame <- function (x, y=NULL, type='l', lty=1:6, lwd=1,
+					pch=1:25, col=NULL, ...) {
+	invisible (points (x=x, y=y, type=type, lty=lty, lwd=lwd, pch=pch,
+			   col=col, ...))
 }
 
 plot.TimeInstantDataFrame <- function (x, y=NULL,
-					type='p', lty=1:6, lwd=1, pch=1:25, col=NULL,
+					type='p', lty=1:6, lwd=1, pch=1:25,
+					col=NULL,
 					xlim=NULL, ylim=NULL,
 					log='', main='', sub='', xlab='', ylab='',
 					ann=par('ann'), axes=TRUE, asp=NA, ...)
@@ -131,13 +147,21 @@ plot.TimeInstantDataFrame <- function (x, y=NULL,
 		axis.POSIXct (1, when(x)) 
 		box()
 	}
-	invisible (points (x=x, y=names(y), type=type, lty=lty, lwd=lwd, pch=pch, col=col,
-			...))
+	invisible (points (x=x, y=names(y), type=type, lty=lty, lwd=lwd, pch=pch,
+			   col=col, ...))
 }
 
+barplot.TimeInstantDataFrame <- function(height, format='', ...) {
+	dots <- list(...)
+	if( !'names.arg' %in% names(dots) )
+		dots$names.arg <- format(when(height), format=format)
+	height <- t(as.data.frame(height))
+	do.call(barplot, c(height=list(height), dots))
+}
 
 points.SubtimeDataFrame <- function (x, y=NULL,
-					type='p', lty=1:6, lwd=1, pch=1:25, col=NULL,
+					type='p', lty=1:6, lwd=1, pch=1:25,
+					col=NULL,
 					as.is=TRUE, ...) {
 	if (is.null(y)) y <- names(x)
 	y <- data.frame (x[y])
@@ -157,8 +181,9 @@ points.SubtimeDataFrame <- function (x, y=NULL,
 		col <- rep (col, length.out=length(y))
 	
 	# plotting
-	trash <- mapply (points, y=y, pch=pch, col=col, type=type, lwd=lwd, lty=lty, ...,
-			MoreArgs=list(x=abscisses))
+	trash <- mapply (points, y=y, pch=pch, col=col, type=type, lwd=lwd,
+			 lty=lty, ...,
+ 			 MoreArgs=list(x=abscisses))
 	pch <- sapply(pch, paste, collapse=', ')
 	if (length(y) > 0)
 		invisible(data.frame (names=names(y), type, lty, lwd, pch, col,
@@ -166,14 +191,16 @@ points.SubtimeDataFrame <- function (x, y=NULL,
 }
 
 lines.SubtimeDataFrame <- function (x, y=NULL,
-					type='l', lty=1:6, lwd=1, pch=1:25, col=NULL,
+					type='l', lty=1:6, lwd=1, pch=1:25,
+					col=NULL,
 					as.is=TRUE, ...) {
 	invisible (points (x=x, y=y, type=type, lty=lty, lwd=lwd, pch=pch, col=col,
 			   as.is=as.is, ...))
 }
 
 plot.SubtimeDataFrame <- function (x, y=NULL,
-					type='p', lty=1:6, lwd=1, pch=1:25, col=NULL,
+					type='p', lty=1:6, lwd=1, pch=1:25,
+					col=NULL,
 					xlim=NULL, ylim=NULL,
 					log='', main='', sub='', xlab='', ylab='',
 					ann=par('ann'), axes=TRUE, asp=NA,
@@ -197,6 +224,15 @@ plot.SubtimeDataFrame <- function (x, y=NULL,
 		axis(1, abscisses, labels=format(when(x), format))
 		box()
 	}
-	invisible (points (x=x, y=names(y), type=type, lty=lty, lwd=lwd, pch=pch, col=col,
-			as.is=as.is, ...))
+	invisible (points (x=x, y=names(y), type=type, lty=lty, lwd=lwd, pch=pch,
+			   col=col, as.is=as.is, ...))
 }
+
+barplot.SubtimeDataFrame <- function(height, format=NULL, ...) {
+	dots <- list(...)
+	if( !'names.arg' %in% names(dots) )
+		dots$names.arg <- format(when(height), format=format)
+	height <- t(as.data.frame(height))
+	do.call(barplot, c(height=list(height), dots))
+}
+
